﻿using Kivii.DataAnnotations;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Kivii.Client.OfficeSample.Entities
{
    public class Task:EntityWithMetadata
    {
        #region 任务基本信息

        /// <summary>
        /// 任务大项名称
        /// </summary>
        public string Title { get; set; }

        /// <summary>
        /// 大项名称和部位
        /// </summary>
        [Ignore]
        public string TitleWithPart
        {
            get
            {
                if (Tag == null) return "";
                return Tag.ToString();
            }
            set
            {
                Tag = value;
            }
        }

        /// <summary>
        /// 大项名称和部位（因为省局和监督是将单位单独列出来显示的，所以在此需要特殊处理，大项后不需要带单位）
        /// </summary>
        [Ignore]
        public string TitleWithPartEx { get; set; }

        /// <summary>
        /// 小项名称和单位
        /// </summary>
        [Ignore]
        public string TitleExWithUnit
        {
            get
            {
                if (ParentKvid == Guid.Empty) return "";//如果是大项，肯定不会生成小项
                if (string.IsNullOrEmpty(Unit)) return TitleEx;//如果大项单位不为空，把小项名称设为空
                return TitleEx + "(" + Unit + ")";
            }
        }

        /// <summary>
        /// 小项名称
        /// </summary>
        public string TitleEx { get; set; }

        /// <summary>
        /// 单位
        /// </summary>
        public string Unit { get; set; }

        /// <summary>
        /// 色号信息
        /// </summary>
        public string Color { get; set; }

        /// <summary>
        /// 色号的排序号
        /// </summary>
        public int ColorSortId { get; set; }

        /// <summary>
        /// 检验部位
        /// </summary>
        public string TitlePart { get; set; }

        /// <summary>
        /// 参考值
        /// </summary>
        public string ReferenceValue { get; set; }

        /// <summary>
        /// 实测值
        /// </summary>
        public string MeasuredValue { get; set; }

        /// <summary>
        /// 合格、不合格、/、""=>四种判定结果
        /// </summary>
        public string IsQualified { get; set; }

        /// <summary>
        /// 是否完成
        /// </summary>
        public bool? IsFinished { get; set; }

        #endregion

        #region 费用信息
        /// <summary>
        /// 理论收费
        /// </summary>
        public decimal Fee { get; set; }

        /// <summary>
        /// 实收费用
        /// </summary>
        public decimal RealFee { get; set; }

        #endregion

        #region 检测组及相关录入人信息
        /// <summary>
        /// 检验小组
        /// </summary>
        public string TaskGroup { get; set; }

        /// <summary>
        /// 录入人
        /// </summary>
        public string Recorder { get; set; }

        /// <summary>
        /// 录入人的Kvid
        /// </summary>
        public Guid RecordKvid { get; set; }
        #endregion

        #region 所属协议及父项Kvid、排序号
        /// <summary>
        /// 所属协议?是否要拆分出任务单
        /// </summary>
        [IgnoreUpdate]
        public Guid ContractKvid { get; set; }

        /// <summary>
        /// 父项Kvid
        /// </summary>
        [IgnoreUpdate]
        public Guid ParentKvid { get; set; }

        /// <summary>
        /// 排序号，尾两位为子项排序号，百位为检测部位排序号，千位及以上为大项排序号
        /// </summary>
        public int SortId { get; set; }

        #endregion

        #region 任务状态
        /// <summary>
        /// 和委托协议同步
        /// </summary>
        public int Flow { get; set; }

        /// <summary>
        ///是否打印,Status=1表示正常状态，Status==2表示被拆分的检验项目，不需打印
        /// </summary>
        [Ignore]
        public bool IsPrint
        {
            get
            {
                return Status == 1;
            }
            set
            {
                Status = value ? 1 : 2;
            }
        }

        #endregion

        #region 关联标准和项目信息

        /// <summary>
        /// 标准排序号,18401为-1，其它的为递增值
        /// </summary>
        public int StandardSortId { get; set; }

        /// <summary>
        /// 标准名称
        /// </summary>
        public string StandardName { get; set; }

        /// <summary>
        /// 标准的代号
        /// </summary>
        public string StandardCode { get; set; }

        /// <summary>
        /// 所属方法标准代号
        /// </summary>
        public string TestCode { get; set; }
        /// <summary>
        /// 检验方法，从检验项目中取出StandardCode
        /// </summary>
        public string TestMethod { get; set; }

        /// <summary>
        /// 检验项目Kvid，以便对应到标准值
        /// </summary>
        [IgnoreUpdate]
        public Guid DetectionKvid { get; set; }

        #endregion

        public string OriginalFile { set; get; }

        public string CheckerName { set; get; }

        public Guid CheckerKvid { set; get; }
    }
    [Route("/Restful/Jst.Lims.Entities.Task/Query")]
    internal class TaskQuery : RestfulQuery<Task>, IReturn<RestfulQueryResponse<Task>>
    {
        public Guid ContractKvid { get; set; }
        public string OrderBy { get; set; }
    }
}
